@@ -161,7 +161,7 @@ __DATA__
 do{ my $x = [
        {
          'additional_cflags' => '-I/usr/include/smpeg -I/usr/include -I/usr/include -I/usr/local/include',
-         'additional_libs' => '-Wl,-rpath,/usr/lib -Wl,-rpath,/usr/local/lib -L/usr/lib -L/usr/local/lib',
+         'additional_libs' => '-L/usr/lib -L/usr/local/lib -Wl,-rpath,/usr/lib -Wl,-rpath,/usr/local/lib',
          'build_arch' => 'armv5tel-linux-thread-multi',
          'build_cc' => 'cc',
          'build_os' => 'linux',
@@ -169,9 +169,9 @@ do{ my $x = [
                              'buildtype' => 'use_config_script',
                              'prefix' => '/usr',
                              'script' => 'sdl-config',
-                             'title' => 'Already installed SDL ver=1.2.15 path=/usr'
+                             'title' => 'Already installed SDL ver=1.2.16 path=/usr'
                            },
-         'build_prefix' => 'sharedir/1.446_54145893',
+         'build_prefix' => 'sharedir/1.446_daf337f1',
          'config' => {
                        'ld_paths' => [],
                        'ld_shared_libs' => [],
